pub enum InboundTlcStatus {
RemoteAnnounced,
AnnounceWaitPrevAck,
AnnounceWaitAck,
Committed,
LocalRemoved,
RemoveAckConfirmed,
}Expand description
The status of an inbound tlc.
Variants
RemoteAnnounced
Received tlc from remote party, but not committed yet
AnnounceWaitPrevAck
We received another AddTlc peer message when we are waiting for the ack of the last one.
AnnounceWaitAck
We have sent commitment signed to peer and waiting ACK for confirming this AddTlc
Committed
We have received ACK from peer and Committed this tlc
LocalRemoved
We have removed this tlc, but haven’t received ACK from peer
RemoveAckConfirmed
We have received the ACK for the RemoveTlc, it’s safe to remove this tlc