pub enum OutboundTlcStatus {
LocalAnnounced,
Committed,
RemoteRemoved,
RemoveWaitPrevAck,
RemoveWaitAck,
RemoveAckConfirmed,
}Expand description
The status of an outbound tlc.
Variants
LocalAnnounced
Offered tlc created and sent to remote party
Committed
Received ACK from remote party for this offered tlc
RemoteRemoved
Remote party removed this tlc
RemoveWaitPrevAck
We received another RemoveTlc message from peer when we are waiting for the ack of the last one.
RemoveWaitAck
We have sent commitment signed to peer and waiting ACK for confirming this RemoveTlc
RemoveAckConfirmed
We have received the ACK for the RemoveTlc, it’s safe to remove this tlc