pub struct Htlc {
pub id: u64,
pub amount: u128,
pub payment_hash: Hash256,
pub expiry: u64,
pub forwarding_channel_id: Option<Hash256>,
pub forwarding_tlc_id: Option<u64>,
pub status: TlcStatus,
}Expand description
The htlc data structure.
Fields
id: u64The id of the htlc
amount: u128The amount of the htlc
payment_hash: Hash256The payment hash of the htlc
expiry: u64The expiry of the htlc
forwarding_channel_id: Option<Hash256>If this HTLC is involved in a forwarding operation, this field indicates the forwarding channel. For an outbound htlc, it is the inbound channel. For an inbound htlc, it is the outbound channel.
forwarding_tlc_id: Option<u64>If this HTLC is involved in a forwarding operation, this field indicates the forwarding tlc id.
status: TlcStatusThe status of the htlc