OpenChannelWithExternalFundingParams

Struct OpenChannelWithExternalFundingParams 

pub struct OpenChannelWithExternalFundingParams {
Show 15 fields pub pubkey: Pubkey, pub funding_amount: u128, pub public: Option<bool>, pub funding_udt_type_script: Option<Script>, pub shutdown_script: Script, pub funding_lock_script: Script, pub funding_lock_script_cell_deps: Option<Vec<CellDep>>, pub commitment_delay_epoch: Option<EpochNumberWithFraction>, pub commitment_fee_rate: Option<u64>, pub funding_fee_rate: Option<u64>, pub tlc_expiry_delta: Option<u64>, pub tlc_min_value: Option<u128>, pub tlc_fee_proportional_millionths: Option<u128>, pub max_tlc_value_in_flight: Option<u128>, pub max_tlc_number_in_flight: Option<u64>,
}
Parameters for opening a channel with external funding.

Fields

pubkey: Pubkey

The identity public key of the peer to open a channel with. The peer must already be connected through the connect_peer rpc first.

funding_amount: u128

The amount of CKB or UDT to fund the channel with.

public: Option<bool>

Whether this is a public channel (will be broadcasted to network, and can be used to forward TLCs), an optional parameter, default value is true.

funding_udt_type_script: Option<Script>

The type script of the UDT to fund the channel with, an optional parameter.

shutdown_script: Script

The script used to receive the channel balance when the channel is closed. This is REQUIRED for external funding.

funding_lock_script: Script

The lock script that controls the funding cells. The node will collect cells with this lock script to build the funding transaction. The user must be able to sign for this lock script.

funding_lock_script_cell_deps: Option<Vec<CellDep>>

Optional extra cell deps required by funding_lock_script. This is useful for custom wallet lock scripts whose deps are not part of the genesis defaults.

commitment_delay_epoch: Option<EpochNumberWithFraction>

The delay time for the commitment transaction, must be an EpochNumberWithFraction in u64 format, an optional parameter, default value is 1 epoch, which is 4 hours.

commitment_fee_rate: Option<u64>

The fee rate for the commitment transaction, an optional parameter.

funding_fee_rate: Option<u64>

The fee rate for the funding transaction, an optional parameter.

tlc_expiry_delta: Option<u64>

The expiry delta to forward a tlc, in milliseconds, default to 4 hours, which is 4 * 60 * 60 * 1000 milliseconds Expect it >= 2/3 commitment_delay_epoch. This parameter can be updated with rpc update_channel later.

tlc_min_value: Option<u128>

The minimum value for a TLC our side can send, an optional parameter, default is 0, which means we can send any TLC is larger than 0. This parameter can be updated with rpc update_channel later.

tlc_fee_proportional_millionths: Option<u128>

The fee proportional millionths for a TLC, proportional to the amount of the forwarded tlc. The unit is millionths of the amount. default is 1000 which means 0.1%. This parameter can be updated with rpc update_channel later.

max_tlc_value_in_flight: Option<u128>

The maximum total value of in-flight TLCs our side will accept from the peer, an optional parameter. This parameter can not be updated after channel is opened.

max_tlc_number_in_flight: Option<u64>

The maximum number of in-flight TLCs our side will accept from the peer, an optional parameter, default is 125 This parameter can not be updated after channel is opened.