pub struct ShutdownChannelParams {
pub channel_id: Hash256,
pub close_script: Option<Script>,
pub fee_rate: Option<u64>,
pub force: Option<bool>,
}Expand description
Parameters for shutting down a channel.
Fields
channel_id: Hash256The channel ID of the channel to shut down
close_script: Option<Script>The script used to receive the channel balance, only support secp256k1_blake160_sighash_all script for now
default is default_funding_lock_script in CkbConfig
fee_rate: Option<u64>The fee rate for the closing transaction, the fee will be deducted from the closing initiator’s channel balance default is 1000 shannons/KW
force: Option<bool>Whether to force the channel to close, when set to false, close_script and fee_rate should be set, default is false.
When set to true, close_script and fee_rate will be ignored and will use the default value when opening the channel.