Module graph

Module graph 

Network graph types for the Fiber Network JSON-RPC API.

Structs

ChannelInfo
The Channel information.
ChannelUpdateInfo
The channel update info with a single direction of channel.
GraphChannelsParams
Parameters for querying graph channels.
GraphChannelsResult
Result of querying graph channels.
GraphNodesParams
Parameters for querying graph nodes.
GraphNodesResult
Result of querying graph nodes.
NodeInfo
The Node information.
UdtArgInfo
The UDT argument info which is used to identify the UDT configuration.
UdtCellDep
The UDT cell dep which is used to identify the UDT configuration for a Fiber Node.
UdtCfgInfos
A list of UDT configuration infos.
UdtDep
Udt script on-chain dependencies.
UdtScript
The UDT script which is used to identify the UDT configuration for a Fiber Node.