pub struct ChannelInfo {
pub channel_outpoint: OutPoint,
pub node1: Pubkey,
pub node2: Pubkey,
pub created_timestamp: u64,
pub update_info_of_node1: Option<ChannelUpdateInfo>,
pub update_info_of_node2: Option<ChannelUpdateInfo>,
pub capacity: u128,
pub chain_hash: Hash256,
pub udt_type_script: Option<Script>,
}Expand description
The Channel information.
Fields
channel_outpoint: OutPointThe outpoint of the channel.
node1: PubkeyThe identity public key of the first node (secp256k1 compressed, hex string).
node2: PubkeyThe identity public key of the second node (secp256k1 compressed, hex string).
created_timestamp: u64The created timestamp of the channel, which is the block header timestamp of the block that contains the channel funding transaction.
update_info_of_node1: Option<ChannelUpdateInfo>The update info from node1 to node2, e.g. timestamp, fee_rate, tlc_expiry_delta, tlc_minimum_value
update_info_of_node2: Option<ChannelUpdateInfo>The update info from node2 to node1, e.g. timestamp, fee_rate, tlc_expiry_delta, tlc_minimum_value
capacity: u128The capacity of the channel.
chain_hash: Hash256The chain hash of the channel.
udt_type_script: Option<Script>The UDT type script of the channel.