NodeInfo

Struct NodeInfo 

pub struct NodeInfo {
    pub node_name: String,
    pub version: String,
    pub addresses: Vec<String>,
    pub features: Vec<String>,
    pub pubkey: Pubkey,
    pub timestamp: u64,
    pub chain_hash: Hash256,
    pub auto_accept_min_ckb_funding_amount: u64,
    pub udt_cfg_infos: UdtCfgInfos,
}
The Node information.

Fields

node_name: String

The name of the node.

version: String

The version of the node.

addresses: Vec<String>

The addresses of the node (serialized as strings).

features: Vec<String>

The node features supported by the node.

pubkey: Pubkey

The identity public key of the node (secp256k1 compressed, hex string), same as pubkey in list_peers.

timestamp: u64

The latest timestamp set by the owner for the node announcement. When a Node is online this timestamp will be updated to the latest value.

chain_hash: Hash256

The chain hash of the node.

auto_accept_min_ckb_funding_amount: u64

The minimum CKB funding amount for automatically accepting open channel requests.

udt_cfg_infos: UdtCfgInfos

The UDT configuration infos of the node.