Module invoice

Module invoice 

Invoice types for the Fiber Network JSON-RPC API.

Structs

CkbInvoice
Represents a syntactically and semantically correct lightning BOLT11 invoice.
GetInvoiceResult
The status of the invoice.
InvoiceData
The metadata of the invoice.
InvoiceParams
Parameters for getting an invoice by payment hash.
InvoiceResult
Result of creating a new invoice.
NewInvoiceParams
The parameter struct for generating a new invoice.
ParseInvoiceParams
Parameters for parsing an invoice.
ParseInvoiceResult
Result of parsing an invoice.
SettleInvoiceParams
Parameters for settling an invoice.
SettleInvoiceResult
Result of settling an invoice.

Enums

Attribute
The attributes of the invoice.
CkbInvoiceStatus
The status of an invoice.
Currency
The currency of the invoice, can also used to represent the CKB network chain.
HashAlgorithm
HashAlgorithm is the hash algorithm used in the hash lock.