NewInvoiceParams

Struct NewInvoiceParams 

pub struct NewInvoiceParams {
    pub amount: u128,
    pub description: Option<String>,
    pub currency: Currency,
    pub payment_preimage: Option<Hash256>,
    pub payment_hash: Option<Hash256>,
    pub expiry: Option<u64>,
    pub fallback_address: Option<String>,
    pub final_expiry_delta: Option<u64>,
    pub udt_type_script: Option<Script>,
    pub hash_algorithm: Option<HashAlgorithm>,
    pub allow_mpp: Option<bool>,
    pub allow_trampoline_routing: Option<bool>,
}
The parameter struct for generating a new invoice.

Fields

amount: u128

The amount of the invoice.

description: Option<String>

The description of the invoice.

currency: Currency

The currency of the invoice.

payment_preimage: Option<Hash256>

The preimage to settle an incoming TLC payable to this invoice. If preimage is set, hash must be absent. If both preimage and hash are absent, a random preimage is generated.

payment_hash: Option<Hash256>

The hash of the preimage. If hash is set, preimage must be absent. This condition indicates a ‘hold invoice’ for which the tlc must be accepted and held until the preimage becomes known.

expiry: Option<u64>

The expiry time of the invoice, in seconds.

fallback_address: Option<String>

The fallback address of the invoice.

final_expiry_delta: Option<u64>

The final HTLC timeout of the invoice, in milliseconds. Minimal value is 16 hours, and maximal value is 14 days.

udt_type_script: Option<Script>

The UDT type script of the invoice.

hash_algorithm: Option<HashAlgorithm>

The hash algorithm of the invoice.

allow_mpp: Option<bool>

Whether allow payment to use MPP

allow_trampoline_routing: Option<bool>

Whether allow payment to use trampoline routing