define_rpc_flags

Macro define_rpc_flags 

macro_rules! define_rpc_flags {
    (
        $(#[$struct_meta:meta])*
        pub struct $name:ident($ty:ty) {
            $($(#[$flag_meta:meta])* const $flag_name:ident = $flag_value:expr;)*
        }
    ) => { ... };
}
Macro to define flags types that serialize to SCREAMING_SNAKE_CASE strings. For single flag, returns the flag name in SCREAMING_SNAKE_CASE (e.g., “OUR_INIT_SENT”). For multiple flags, returns pipe-separated names (e.g., “OUR_INIT_SENT | THEIR_INIT_SENT”).