Module payment

Module payment 

Payment types for the Fiber Network JSON-RPC API.

Structs

BuildPaymentRouterResult
The router returned by build_router.
BuildRouterParams
Parameters for building a payment router.
GetPaymentCommandParams
Parameters for getting a payment.
GetPaymentCommandResult
The result of a get_payment command, which includes the payment hash, status, timestamps, error message if failed, fee paid, and custom records.
HopHint
A hop hint is a hint for a node to use a specific channel.
HopRequire
A hop requirement to meet when building a router. Does not include the source node; the last hop is the target node.
ListPaymentsParams
Parameters for listing payments.
ListPaymentsResult
Result of listing payments.
PaymentCustomRecords
The custom records to be included in the payment. The key is hex encoded of u32, it’s range limited in 0 ~ 65535, and the value is hex encoded of Vec<u8> with 0x as prefix. For example:
RouterHop
A router hop information for a payment, a paymenter router is an array of RouterHop, a router hop generally implies hop target will receive amount_received with channel_outpoint of channel.
SendPaymentCommandParams
Parameters for sending a payment.
SendPaymentWithRouterParams
Parameters for sending a payment with a specified router.
SessionRoute
The router is a list of nodes that the payment will go through.
SessionRouteNode
The node and channel information in a payment route hop.

Enums

PaymentStatus
The status of a payment, will update as the payment progresses. The transfer path for payment status is Created -> Inflight -> Success | Failed.