pub struct GetPaymentCommandResult {
pub payment_hash: Hash256,
pub payment_preimage: Option<Hash256>,
pub status: PaymentStatus,
pub created_at: u64,
pub last_updated_at: u64,
pub failed_error: Option<String>,
pub fee: u128,
pub custom_records: Option<PaymentCustomRecords>,
pub routers: Vec<SessionRoute>,
}Expand description
The result of a get_payment command, which includes the payment hash, status, timestamps, error message if failed, fee paid, and custom records.
Fields
payment_hash: Hash256The payment hash of the payment
payment_preimage: Option<Hash256>The preimage learned from a successful payment attempt.
status: PaymentStatusThe status of the payment
created_at: u64The time the payment was created at, in milliseconds from UNIX epoch
last_updated_at: u64The time the payment was last updated at, in milliseconds from UNIX epoch
failed_error: Option<String>The error message if the payment failed
fee: u128fee paid for the payment
custom_records: Option<PaymentCustomRecords>The custom records to be included in the payment.
routers: Vec<SessionRoute>The router is a list of nodes that the payment will go through.
We store in the payment session and then will use it to track the payment history.
If the payment adapted MPP (multi-part payment), the routers will be a list of nodes.
For example:
A(amount, channel) -> B -> C -> D
means A will send amount with channel to B.