pub struct HopHint {
pub pubkey: Pubkey,
pub channel_outpoint: OutPoint,
pub fee_rate: u64,
pub tlc_expiry_delta: u64,
}Expand description
A hop hint is a hint for a node to use a specific channel.
Fields
pubkey: PubkeyThe public key of the node
channel_outpoint: OutPointThe outpoint of the channel
fee_rate: u64The fee rate to use this hop to forward the payment.
tlc_expiry_delta: u64The TLC expiry delta to use this hop to forward the payment.