Module peer

Module peer 

Peer management types for the Fiber Network JSON-RPC API.

Structs

ConnectPeerParams
Parameters for connecting to a peer.
DisconnectPeerParams
Parameters for disconnecting from a peer.
ListPeersResult
The result of the list_peers RPC method.
PeerInfo
The information about a peer connected to the node.

Enums

TransportType
The type of transport to filter by when resolving peer addresses.