pub struct PeerInfo {
pub pubkey: Pubkey,
pub address: String,
}Expand description
The information about a peer connected to the node.
Fields
pubkey: PubkeyThe identity public key of the peer.
address: StringThe multi-address associated with the connecting peer (as a string).
Note: this is only the address which used for connecting to the peer, not all addresses of the peer.
The graph_nodes in Graph rpc module will return all addresses of the peer.