pub struct AcceptChannelParams {
pub temporary_channel_id: Hash256,
pub funding_amount: u128,
pub shutdown_script: Option<Script>,
pub max_tlc_value_in_flight: Option<u128>,
pub max_tlc_number_in_flight: Option<u64>,
pub tlc_min_value: Option<u128>,
pub tlc_fee_proportional_millionths: Option<u128>,
pub tlc_expiry_delta: Option<u64>,
}Expand description
Parameters for accepting a channel.
Fields
temporary_channel_id: Hash256The temporary channel ID of the channel to accept
funding_amount: u128The amount of CKB or UDT to fund the channel with
shutdown_script: Option<Script>The script used to receive the channel balance, an optional parameter, default value is the secp256k1_blake160_sighash_all script corresponding to the configured private key
max_tlc_value_in_flight: Option<u128>The maximum total value of in-flight TLCs our side will accept from the peer, default is u128::MAX This parameter can not be updated after channel is opened.
max_tlc_number_in_flight: Option<u64>The maximum number of in-flight TLCs our side will accept from the peer, default is 125 This parameter can not be updated after channel is opened.
tlc_min_value: Option<u128>The minimum value for a TLC our side can send,
an optional parameter, default is 0, which means we can send any TLC is larger than 0.
This parameter can be updated with rpc update_channel later.
tlc_fee_proportional_millionths: Option<u128>The fee proportional millionths for a TLC, proportional to the amount of the forwarded tlc.
The unit is millionths of the amount. default is 1000 which means 0.1%.
This parameter can be updated with rpc update_channel later.
Not that, we use outbound channel to calculate the fee for TLC forwarding. For example,
if we have a path A -> B -> C, then the fee B requires for TLC forwarding, is calculated
the channel configuration of B and C, not A and B.
tlc_expiry_delta: Option<u64>The expiry delta to forward a tlc, in milliseconds, default to 1 day, which is 24 * 60 * 60 * 1000 milliseconds
This parameter can be updated with rpc update_channel later.