Network graph types for the Fiber Network JSON-RPC API.
Structs
- Channel
Info - The Channel information.
- Channel
Update Info - The channel update info with a single direction of channel.
- Graph
Channels Params - Parameters for querying graph channels.
- Graph
Channels Result - Result of querying graph channels.
- Graph
Nodes Params - Parameters for querying graph nodes.
- Graph
Nodes Result - Result of querying graph nodes.
- Node
Info - The Node information.
- UdtArg
Info - The UDT argument info which is used to identify the UDT configuration.
- UdtCell
Dep - The UDT cell dep which is used to identify the UDT configuration for a Fiber Node.
- UdtCfg
Infos - A list of UDT configuration infos.
- UdtDep
- Udt script on-chain dependencies.
- UdtScript
- The UDT script which is used to identify the UDT configuration for a Fiber Node.