pub struct NodeInfo {
pub node_name: String,
pub version: String,
pub addresses: Vec<String>,
pub features: Vec<String>,
pub pubkey: Pubkey,
pub timestamp: u64,
pub chain_hash: Hash256,
pub auto_accept_min_ckb_funding_amount: u64,
pub udt_cfg_infos: UdtCfgInfos,
}Expand description
The Node information.
Fields
node_name: StringThe name of the node.
version: StringThe version of the node.
addresses: Vec<String>The addresses of the node (serialized as strings).
features: Vec<String>The node features supported by the node.
pubkey: PubkeyThe identity public key of the node (secp256k1 compressed, hex string), same as pubkey in list_peers.
timestamp: u64The latest timestamp set by the owner for the node announcement. When a Node is online this timestamp will be updated to the latest value.
chain_hash: Hash256The chain hash of the node.
auto_accept_min_ckb_funding_amount: u64The minimum CKB funding amount for automatically accepting open channel requests.
udt_cfg_infos: UdtCfgInfosThe UDT configuration infos of the node.