pub struct NodeInfoResult {Show 17 fields
pub version: String,
pub commit_hash: String,
pub pubkey: Pubkey,
pub features: Vec<String>,
pub node_name: Option<String>,
pub addresses: Vec<String>,
pub chain_hash: Hash256,
pub open_channel_auto_accept_min_ckb_funding_amount: u64,
pub auto_accept_channel_ckb_funding_amount: u64,
pub default_funding_lock_script: Script,
pub tlc_expiry_delta: u64,
pub tlc_min_value: u128,
pub tlc_fee_proportional_millionths: u128,
pub channel_count: u32,
pub pending_channel_count: u32,
pub peers_count: u32,
pub udt_cfg_infos: UdtCfgInfos,
}Expand description
Node information result.
Fields
version: StringThe version of the node software.
commit_hash: StringThe commit hash of the node software.
pubkey: PubkeyThe identity public key of this node (secp256k1 compressed, hex without 0x prefix).
features: Vec<String>The features supported by the node.
node_name: Option<String>The optional name of the node.
addresses: Vec<String>A list of multi-addresses associated with the node (as strings).
chain_hash: Hash256The hash of the blockchain that the node is connected to.
open_channel_auto_accept_min_ckb_funding_amount: u64The minimum CKB funding amount for automatically accepting open channel requests, serialized as a hexadecimal string.
auto_accept_channel_ckb_funding_amount: u64The CKB funding amount for automatically accepting channel requests, serialized as a hexadecimal string.
default_funding_lock_script: ScriptThe default funding lock script for the node.
tlc_expiry_delta: u64The locktime expiry delta for Time-Locked Contracts (TLC), serialized as a hexadecimal string.
tlc_min_value: u128The minimum value for Time-Locked Contracts (TLC) we can send, serialized as a hexadecimal string.
tlc_fee_proportional_millionths: u128The fee (to forward payments) proportional to the value of Time-Locked Contracts (TLC), expressed in millionths and serialized as a hexadecimal string.
channel_count: u32The number of channels associated with the node, serialized as a hexadecimal string.
pending_channel_count: u32The number of pending channels associated with the node, serialized as a hexadecimal string.
peers_count: u32The number of peers connected to the node, serialized as a hexadecimal string.
udt_cfg_infos: UdtCfgInfosConfiguration information for User-Defined Tokens (UDT) associated with the node.