Invoice types for the Fiber Network JSON-RPC API.
Structs
- CkbInvoice
- Represents a syntactically and semantically correct lightning BOLT11 invoice.
- GetInvoice
Result - The status of the invoice.
- Invoice
Data - The metadata of the invoice.
- Invoice
Params - Parameters for getting an invoice by payment hash.
- Invoice
Result - Result of creating a new invoice.
- NewInvoice
Params - The parameter struct for generating a new invoice.
- Parse
Invoice Params - Parameters for parsing an invoice.
- Parse
Invoice Result - Result of parsing an invoice.
- Settle
Invoice Params - Parameters for settling an invoice.
- Settle
Invoice Result - Result of settling an invoice.
Enums
- Attribute
- The attributes of the invoice.
- CkbInvoice
Status - The status of an invoice.
- Currency
- The currency of the invoice, can also used to represent the CKB network chain.
- Hash
Algorithm - HashAlgorithm is the hash algorithm used in the hash lock.