Payment types for the Fiber Network JSON-RPC API.
Structs
- Build
Payment Router Result - The router returned by build_router.
- Build
Router Params - Parameters for building a payment router.
- GetPayment
Command Params - Parameters for getting a payment.
- GetPayment
Command Result - The result of a get_payment command, which includes the payment hash, status, timestamps, error message if failed, fee paid, and custom records.
- HopHint
- A hop hint is a hint for a node to use a specific channel.
- HopRequire
- A hop requirement to meet when building a router. Does not include the source node; the last hop is the target node.
- List
Payments Params - Parameters for listing payments.
- List
Payments Result - Result of listing payments.
- Payment
Custom Records - The custom records to be included in the payment.
The key is hex encoded of
u32, it’s range limited in 0 ~ 65535, and the value is hex encoded ofVec<u8>with0xas prefix. For example: - Router
Hop - A router hop information for a payment, a paymenter router is an array of RouterHop,
a router hop generally implies hop
targetwill receiveamount_receivedwithchannel_outpointof channel. - Send
Payment Command Params - Parameters for sending a payment.
- Send
Payment With Router Params - Parameters for sending a payment with a specified router.
- Session
Route - The router is a list of nodes that the payment will go through.
- Session
Route Node - The node and channel information in a payment route hop.
Enums
- Payment
Status - The status of a payment, will update as the payment progresses.
The transfer path for payment status is
Created -> Inflight -> Success | Failed.