pub struct SendPaymentWithRouterParams {
pub payment_hash: Option<Hash256>,
pub router: Vec<RouterHop>,
pub invoice: Option<String>,
pub custom_records: Option<PaymentCustomRecords>,
pub keysend: Option<bool>,
pub udt_type_script: Option<Script>,
pub dry_run: Option<bool>,
}Expand description
Parameters for sending a payment with a specified router.
Fields
payment_hash: Option<Hash256>the hash to use within the payment’s HTLC.
If not set and keysend is set to true, a random hash will be generated.
If not set and there is a payment_hash in the invoice, it will be used.
Otherwise, payment_hash need to be set.
router: Vec<RouterHop>The router to use for the payment
invoice: Option<String>the encoded invoice to send to the recipient
custom_records: Option<PaymentCustomRecords>Some custom records for the payment which contains a map of u32 to Vec
For example:
"custom_records": {
"0x1": "0x01020304",
"0x2": "0x05060708",
"0x3": "0x090a0b0c",
"0x4": "0x0d0e0f10010d090a0b0c"
}keysend: Option<bool>keysend payment
udt_type_script: Option<Script>udt type script for the payment
dry_run: Option<bool>dry_run for payment, used for check whether we can build valid router and the fee for this payment, it’s useful for the sender to double check the payment before sending it to the network, default is false